@@ -1,7 +1,7 @@
 package App::PDRUtils::DistIniCmd::add_prereq;
 
 our $DATE = '2016-03-03'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,9 +48,11 @@ sub handle_cmd {
 
     my $section;
     for my $s ($iod->list_sections) {
-        next unless $s =~ m!\Aprereqs(?:\s*/\s*(\w+))?\z!;
+        next unless $s =~ m!\Aprereqs(?:\s*/\s*(\w+))?\z!ix;
         if ($phase eq 'runtime' && $rel eq 'requires') {
             next unless !$1 || lc($1) eq 'runtimerequires';
+        } else {
+            next unless  $1 && lc($1) eq $phase.$rel;
         }
         $section = $s;
         last;
@@ -88,7 +90,7 @@ App::PDRUtils::DistIniCmd::add_prereq - Add a prereq
 
 =head1 VERSION
 
-This document describes version 0.04 of App::PDRUtils::DistIniCmd::add_prereq (from Perl distribution App-PDRUtils), released on 2016-03-03.
+This document describes version 0.05 of App::PDRUtils::DistIniCmd::add_prereq (from Perl distribution App-PDRUtils), released on 2016-03-03.
 
 =head1 FUNCTIONS
 
