@@ -1,7 +1,7 @@
 package App::PDRUtils::MultiCmd::add_prereq;
 
 our $DATE = '2016-03-03'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,7 +28,7 @@ App::PDRUtils::MultiCmd::add_prereq - Add a prereq
 
 =head1 VERSION
 
-This document describes version 0.04 of App::PDRUtils::MultiCmd::add_prereq (from Perl distribution App-PDRUtils), released on 2016-03-03.
+This document describes version 0.05 of App::PDRUtils::MultiCmd::add_prereq (from Perl distribution App-PDRUtils), released on 2016-03-03.
 
 =head1 FUNCTIONS
 
@@ -46,9 +46,13 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<depends> => I<str>
+=item * B<depends> => I<array[str]>
 
-Only include repos that has prereq to a specified module.
+Only include repos that has prereq to specified module(s).
+
+=item * B<doesnt_depend> => I<array[str]>
+
+Exclude repos that has prereq to specified module(s).
 
 =item * B<exclude_dist_patterns> => I<array[str]>
 
